==> pan-0.12.91.tar.gz: pan-0.12.91/pan/gui-headers.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Author: Charles Kerr <charles@rebelbase.com>
 *
 * Copyright (C) 2000, 2001  Pan Development Team <pan@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __GUI_HEADERS_H__
#define __GUI_HEADERS_H__

#include <glib.h>
#include <gtk/gtkwidget.h>
#include <gmime/gmime-message.h>
#include <pan/base/article.h>

/**
 * These are the flgs passed in via the "header_fields" argument in
 * the function gui_set_headers().  For each flag, that header will
 * be displayed.
 */
enum {
	UI_HEADER_SUBJECT	= 1<<0,
	UI_HEADER_AUTHOR	= 1<<1,
	UI_HEADER_MESSAGE_ID	= 1<<2,
	UI_HEADER_REFERENCES	= 1<<3,
	UI_HEADER_REPLY_TO	= 1<<4,
	UI_HEADER_FOLLOWUP_TO	= 1<<5,
	UI_HEADER_DATE		= 1<<6,
	UI_HEADER_NEWSGROUPS	= 1<<7,
	UI_HEADER_NEWSREADER	= 1<<8
};

/**
 * This variable is initialized in prefs_init() and defines the user-settable
 * default headers to be displayed.  This is an or'ed list of items from the
 * above enumeration.
 */
extern gulong header_flags;

/**
 * Updates the specified GtkTable to show the specified header_fields
 * associated with the article struct.  If a header is too long to fit
 * conveniently, it is truncated in a hopefully-reasonable way and
 * displayed as a button insted of a label.  When this button is clicked,
 * the untruncated header will be shown in a popup dialog.
 *
 * @param GtkTable the gtktable to use.  Its previous contents are removed.
 * @param Article the article whose headers to use.
 * @param header_fields which headers to show.
 */
void gui_headers_set_nolock       (GtkWidget         * gtk_table,
                                   GMimeMessage      * message,
                                   gulong              header_fields);

/**
 * The same as gui_set_headers, but uses the default header_fields specified
 * in the user's configuration file.  This is a convenience so that callers
 * don't have to query the configuration file by hand.
 */
void gui_headers_set_default_nolock      (GtkWidget         * table,
                                          GMimeMessage      * message);

#endif /* __GUI_HEADERS_H__ */

==> pan-0.14.1.tar.gz: pan-0.14.1/pan/gui-headers.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Pan - A Newsreader for Gtk+
 * Copyright (C) 2002  Charles Kerr <charles@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __GUI_HEADERS_H__
#define __GUI_HEADERS_H__

#include <glib.h>
#include <gtk/gtkwidget.h>
#include <gmime/gmime-message.h>
#include <pan/base/article.h>

/**
 * These are the flgs passed in via the "header_fields" argument in
 * the function gui_set_headers().  For each flag, that header will
 * be displayed.
 */
enum {
	UI_HEADER_SUBJECT	= 1<<0,
	UI_HEADER_AUTHOR	= 1<<1,
	UI_HEADER_MESSAGE_ID	= 1<<2,
	UI_HEADER_REFERENCES	= 1<<3,
	UI_HEADER_REPLY_TO	= 1<<4,
	UI_HEADER_FOLLOWUP_TO	= 1<<5,
	UI_HEADER_DATE		= 1<<6,
	UI_HEADER_NEWSGROUPS	= 1<<7,
	UI_HEADER_NEWSREADER	= 1<<8
};

/**
 * This variable is initialized in prefs_init() and defines the user-settable
 * default headers to be displayed.  This is an or'ed list of items from the
 * above enumeration.
 */
extern gulong header_flags;

/**
 * Updates the specified GtkTable to show the specified header_fields
 * associated with the article struct.  If a header is too long to fit
 * conveniently, it is truncated in a hopefully-reasonable way and
 * displayed as a button insted of a label.  When this button is clicked,
 * the untruncated header will be shown in a popup dialog.
 *
 * @param GtkTable the gtktable to use.  Its previous contents are removed.
 * @param GMimeMessage the article whose headers to use.
 * @param header_fields which headers to show.
 */
void gui_headers_set_nolock       (GtkWidget         * gtk_table,
                                   GMimeMessage      * message,
                                   gulong              header_fields);

/**
 * The same as gui_set_headers, but uses the default header_fields specified
 * in the user's configuration file.  This is a convenience so that callers
 * don't have to query the configuration file by hand.
 */
void gui_headers_set_default_nolock      (GtkWidget         * table,
                                          GMimeMessage      * message);

#endif /* __GUI_HEADERS_H__ */
